<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

    <xsl:output method="html"/>

    <xsl:variable name="chapter_count" select="count(//chapter)"/>

    <xsl:template match="/book|/article">
        <html>
            <head>
                <title>
                    <xsl:apply-templates select="title"/>
                </title>
            </head>
            <body>
                <xsl:apply-templates select="title" mode="h1"/>
                <xsl:apply-templates select="author">
                    <xsl:sort select="surname"/>
                </xsl:apply-templates>
                <ul>
                    <xsl:apply-templates select="chapter" mode="toc"/>
                </ul>
                <xsl:apply-templates select="chapter"/>
                <xsl:call-template name="footer">
                    <xsl:with-param name="year" select="'March 2008'"/>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="title[parent::book]">
        Kniha:
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="title[parent::article]">
        Clanek:
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="title" mode="h1">
        <h1>
            <xsl:value-of select="."/>
        </h1>
    </xsl:template>

    <xsl:template match="title[parent::book]">
        Kniha:
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="title">
    </xsl:template>

    <xsl:template match="chapter" mode="toc">
        <li><a href="#{generate-id(.)}"><xsl:value-of select="title"/></a></li>
    </xsl:template>
    
    <xsl:template match="chapter">
        <div>
            <a name="{generate-id(.)}"/>
            <h2>Kapitola
                <xsl:number value="position()" format="I. "/>
                <xsl:value-of select="title"/>
            </h2>
            <xsl:apply-templates/>
        </div>
    </xsl:template>

    <xsl:template name="footer">
        <xsl:param name="year" select="2009"/>
        This
        <xsl:choose>
            <xsl:when test="local-name()='book'">book</xsl:when>
            <xsl:when test="local-name()='article'">article</xsl:when>
            <xsl:otherwise>(unknown publication)</xsl:otherwise>
        </xsl:choose>
        has <xsl:value-of select="$chapter_count"/>
        chapter<xsl:if test="not($chapter_count=1)">s</xsl:if>.
        <hr/>
        <p align="right">
            <em>Created by TP, <xsl:value-of select="$year"/></em>
        </p>
    </xsl:template>

    <xsl:template match="author">
        <xsl:value-of select="firstname"/>&#160;
        <xsl:value-of select="surname"/>
        <xsl:if test="following-sibling::author">, </xsl:if>
    </xsl:template>

</xsl:stylesheet>
